==> ob_dj_otp-0.0.13-py3-none-any.whl: ob_dj_otp/apis/otp/views.py <==
import logging

from django.utils.decorators import method_decorator
from drf_yasg.utils import swagger_auto_schema
from rest_framework import mixins, permissions, viewsets

from ob_dj_otp.apis.otp.serializers import (
    OTPRequestCodeSerializer,
    OTPVerifyCodeSerializer,
)
from ob_dj_otp.core.otp import app_settings, import_str_to_object

logger = logging.getLogger(__name__)


@method_decorator(
    name="create",
    decorator=swagger_auto_schema(
        operation_summary="OTP Auth & Register",
        operation_description="""
        OTP Endpoint can be used for authentication or registration.

        *Auth*:

        - Request `POST /{version}/otp/` with `phone_number`
        The backend will send a verification code for the specified number if a matching user found.
        - Request `POST /{version}/otp/` with `phone_number` and `verification_code`
        The backend will validate the code and return access and refresh token

        """,
        tags=["OTP Auth",],
        responses={},
    ),
)
class OneTimePairingViewSet(mixins.CreateModelMixin, viewsets.GenericViewSet):
    permission_classes = [
        permissions.AllowAny,
    ]

    def get_serializer_class(self):
        if "verification_code" in self.request.data.keys():
            # If no verification serializer set use default
            if not app_settings.VERIFICATION_SERIALIZER:
                return OTPVerifyCodeSerializer
            return import_str_to_object(app_settings.VERIFICATION_SERIALIZER)
        return OTPRequestCodeSerializer

==> ob_dj_otp-0.0.22-py3-none-any.whl: ob_dj_otp/apis/otp/views.py <==
import logging

from django.utils.decorators import method_decorator
from drf_yasg.utils import swagger_auto_schema
from rest_framework import mixins, permissions, viewsets
from rest_framework.decorators import action

from ob_dj_otp.apis.otp.serializers import (
    OTPRequestCodeSerializer,
    OTPVerifyCodeSerializer,
)

logger = logging.getLogger(__name__)


@method_decorator(
    name="create",
    decorator=swagger_auto_schema(
        operation_summary="OTP Auth & Register",
        operation_description="""
        OTP Endpoint can be used for authentication or registration.

        *Auth*:

        - Request `POST /{version}/otp/` with `phone_number` or `email`
        The backend will send a verification code for the specified number if a matching user found.

        """,
        tags=["OTP Auth",],
        responses={},
    ),
)
@method_decorator(
    name="verify",
    decorator=swagger_auto_schema(
        operation_summary="OTP Verify code",
        operation_description="""
        OTP Endpoint can be used for verifying the code.
        - Request `POST /{version}/otp/` with `phone_number` or `email` and `verification_code`
        The backend will validate the code and return access and refresh token

        """,
        tags=["OTP Auth",],
        responses={},
    ),
)
class OneTimePairingViewSet(mixins.CreateModelMixin, viewsets.GenericViewSet):
    permission_classes = [
        permissions.AllowAny,
    ]
    serializer_class = OTPRequestCodeSerializer

    @action(
        detail=False,
        methods=["POST"],
        url_path="verify",
        serializer_class=OTPVerifyCodeSerializer,
    )
    def verify(self, request, *args, **kwargs):
        return super().create(request, *args, **kwargs)
